==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts.md <==
# AwsIdentityAccessManagementAwsSts


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts')
```



| Illustration | AwsIdentityAccessManagementAwsSts | AwsIdentityAccessManagementAwsStsCard | AwsIdentityAccessManagementAwsStsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts.png) | ![illustration for AwsIdentityAccessManagementAwsSts](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts.Local.png) | ![illustration for AwsIdentityAccessManagementAwsStsCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsCard.Local.png) | ![illustration for AwsIdentityAccessManagementAwsStsGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsGroup.Local.png) |




## AwsIdentityAccessManagementAwsSts

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsSts
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts')

' renders the element
AwsIdentityAccessManagementAwsSts('AwsIdentityAccessManagementAwsSts', 'Aws Identity Access Management Aws Sts', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsSts
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts')

' renders the element
AwsIdentityAccessManagementAwsSts('AwsIdentityAccessManagementAwsSts', 'Aws Identity Access Management Aws Sts', 'an optional tech label')
@enduml
```

## AwsIdentityAccessManagementAwsStsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts')

' renders the element
AwsIdentityAccessManagementAwsStsCard('AwsIdentityAccessManagementAwsStsCard', 'Aws Identity Access Management Aws Sts Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts')

' renders the element
AwsIdentityAccessManagementAwsStsCard('AwsIdentityAccessManagementAwsStsCard', 'Aws Identity Access Management Aws Sts Card', 'an optional description')
@enduml
```

## AwsIdentityAccessManagementAwsStsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts')

' renders the element
AwsIdentityAccessManagementAwsStsGroup('AwsIdentityAccessManagementAwsStsGroup', 'Aws Identity Access Management Aws Sts Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts')

' renders the element
AwsIdentityAccessManagementAwsStsGroup('AwsIdentityAccessManagementAwsStsGroup', 'Aws Identity Access Management Aws Sts Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts.md <==
# AwsIdentityAccessManagementAwsSts


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts')
```



| Illustration | AwsIdentityAccessManagementAwsSts | AwsIdentityAccessManagementAwsStsCard | AwsIdentityAccessManagementAwsStsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts.png) | ![illustration for AwsIdentityAccessManagementAwsSts](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts.Local.png) | ![illustration for AwsIdentityAccessManagementAwsStsCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsCard.Local.png) | ![illustration for AwsIdentityAccessManagementAwsStsGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsStsGroup.Local.png) |




## AwsIdentityAccessManagementAwsSts

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsSts
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts')

' renders the element
AwsIdentityAccessManagementAwsSts('AwsIdentityAccessManagementAwsSts', 'Aws Identity Access Management Aws Sts', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsSts
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts')

' renders the element
AwsIdentityAccessManagementAwsSts('AwsIdentityAccessManagementAwsSts', 'Aws Identity Access Management Aws Sts', 'an optional tech label')
@enduml
```

## AwsIdentityAccessManagementAwsStsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts')

' renders the element
AwsIdentityAccessManagementAwsStsCard('AwsIdentityAccessManagementAwsStsCard', 'Aws Identity Access Management Aws Sts Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts')

' renders the element
AwsIdentityAccessManagementAwsStsCard('AwsIdentityAccessManagementAwsStsCard', 'Aws Identity Access Management Aws Sts Card', 'an optional description')
@enduml
```

## AwsIdentityAccessManagementAwsStsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts')

' renders the element
AwsIdentityAccessManagementAwsStsGroup('AwsIdentityAccessManagementAwsStsGroup', 'Aws Identity Access Management Aws Sts Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAwsStsGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAwsSts')

' renders the element
AwsIdentityAccessManagementAwsStsGroup('AwsIdentityAccessManagementAwsStsGroup', 'Aws Identity Access Management Aws Sts Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
